@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.7';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -15,8 +15,8 @@ has log_encoding        => undef;      #utf8|gbk|...
 
 has tmpdir              => sub {File::Spec->tmpdir();};
 has media_dir           => sub {$_[0]->tmpdir};
-has cookie_dir          => sub {return $_[0]->tmpdir;};
-has qrcode_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_qrcode','.png'))};
+has cookie_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_cookie','.dat'))};
+has qrcode_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_qrcode','.jpg'))};
 has ioloop              => sub {Mojo::IOLoop->singleton};
 has keep_cookie         => 1;
 
