@@ -6,6 +6,7 @@ use Mojo::Weixin::Client::Remote::_is_need_login;
 use Mojo::Weixin::Client::Remote::_synccheck;
 use Mojo::Weixin::Client::Remote::_sync;
 use Mojo::Weixin::Message::Handle;
+use Mojo::IOLoop::Delay;
 
 use base qw(Mojo::Weixin::Request Mojo::Weixin::Client::Cron);
 
@@ -55,6 +56,14 @@ sub relogin{
 sub logout{
     my $self = shift;
 }
+sub steps {
+    my $self = shift;
+    Mojo::IOLoop::Delay->new(ioloop=>$self->ioloop)->steps(@_)->catch(sub {
+        my ($delay, $err) = @_;
+        $self->error("steps error: $err");
+    })->wait;
+    $self;
+}
 sub ready {
     my $self = shift;
     #加载插件
@@ -99,12 +108,11 @@ sub clean_qrcode{
 
 sub timer {
     my $self = shift;
-    $self->ioloop->timer(@_);
-    return $self;
+    return $self->ioloop->timer(@_);
 }
 sub interval{
     my $self = shift;
-    $self->ioloop->recurring(@_);
+    return $self->ioloop->recurring(@_);
 }
 
 sub exit{
