@@ -6,7 +6,7 @@ sub Mojo::Weixin::_synccheck{
         return;
     }
     $self->_synccheck_running(1);
-    my $api = "https://webpush.weixin.qq.com/cgi-bin/mmwebwx-bin/synccheck";
+    my $api = "https://". ($self->domain eq "wx2.qq.com"?"webpush2.weixin.qq.com":"webpush.weixin.qq.com") . "/cgi-bin/mmwebwx-bin/synccheck";
     my $callback = sub {
         my $data = shift;
         #window.synccheck={retcode:"0",selector:"0"}
@@ -15,15 +15,14 @@ sub Mojo::Weixin::_synccheck{
         $self->emit("synccheck_over",$retcode,$selector); 
     };
     my @query_string = (
-        skey        =>  $self->skey,
-        callback    =>  "jQuery1830847224326338619_" . $self->now(),
         r           =>  $self->now(),
+        skey        =>  $self->skey,
         sid         =>  $self->wxsid,
         uin         =>  $self->wxuin,
         deviceid    =>  $self->deviceid,
         synckey     =>  join("|",map {$_->{Key} . "_" . $_->{Val};} @{$self->sync_key->{List}}),
         _           =>  $self->now(),
     );
-    $self->http_get($self->gen_url2($api,@query_string),$callback);
+    $self->http_get($self->gen_url2($api,@query_string),{Referer=>"https://" .$self->domain . "/"},$callback);
 }
 1;
