@@ -8,6 +8,9 @@ use Mojo::Weixin::Message::SendStatus;
 use Mojo::Weixin::Const;
 use Mojo::Weixin::Message::SendStatus;
 use Mojo::Weixin::Message::Queue;
+use Mojo::Weixin::Message::Remote::_upload_media;
+use Mojo::Weixin::Message::Remote::_get_media;
+use Mojo::Weixin::Message::Remote::_send_media_message;
 use Mojo::Weixin::Message::Remote::_send_text_message;
 $Mojo::Weixin::Message::LAST_DISPATCH_TIME  = undef;
 $Mojo::Weixin::Message::SEND_INTERVAL  = 3;
@@ -20,6 +23,14 @@ sub gen_message_queue{
         return if $self->is_stop;
         if($msg->class eq "recv"){
             $self->emit(receive_message=>$msg);
+            if($msg->format eq "media"){
+                if($self->has_subscribers("receive_media")){
+                    $self->_get_media($msg->media_id,sub{
+                        my ($path,$data) = @_;
+                        $self->emit(receive_media=>$path,$data,$msg->sender);
+                    });
+                }
+            }
         }
         elsif($msg->class eq "send"){
             if($msg->source ne "local"){
@@ -66,7 +77,12 @@ sub gen_message_queue{
             }
             $self->timer($delay,sub{
                 $msg->time(time);
-                $self->_send_text_message($msg);
+                if($msg->format eq "text"){
+                    $self->_send_text_message($msg);
+                }
+                elsif($msg->format eq "media"){
+                    $self->_send_media_message($msg);
+                }
             });
             $Mojo::Weixin::Message::LAST_DISPATCH_TIME = $now+$delay;
         }
@@ -171,47 +187,62 @@ sub _parse_sync_data {
     #有新消息
     if($json->{AddMsgCount} != 0){
         for my $e (@{$json->{AddMsgList}}){
+            my $msg = {};
+            for(keys %KEY_MAP_MESSAGE){
+                $msg->{$_} = defined $e->{$KEY_MAP_MESSAGE{$_}}?encode("utf8",$e->{$KEY_MAP_MESSAGE{$_}}):"";
+            }
             if($e->{MsgType} == 1){
-                my $msg = {};
                 $msg->{format} = "text";
-                for(keys %KEY_MAP_MESSAGE){$msg->{$_} = defined $e->{$KEY_MAP_MESSAGE{$_}}?encode("utf8",$e->{$KEY_MAP_MESSAGE{$_}}):"";}
+            }
+            elsif($e->{MsgType} == 3){#图片消息
+                $msg->{format} = "media";
+                $msg->{media_id} = $msg->{id};
+            }
+            else{next;}
+            if(defined $msg->{content}){
                 eval{
                     require HTML::Entities;
                     $msg->{content} = HTML::Entities::decode_entities($msg->{content});
                 };
-                if($e->{FromUserName} eq $self->user->id){#发送的消息
-                    $msg->{source} = 'outer';
-                    $msg->{class} = "send";
-                    $msg->{sender_id} = $self->user->id;
-                    if($self->is_group($e->{ToUserName})){
-                        $msg->{type} = "group_message";
-                        $msg->{group_id} = $e->{ToUserName};
-                    }
-                    else{
-                        $msg->{type} = "friend_message";
-                        $msg->{receiver_id} = $e->{ToUserName};
+                if($@){
+                    eval{
+                        $msg->{content} = Mojo::Util::html_unescape($msg->{content});
+                    };
+                    if($@){$self->warn("html entities unescape fail: $@")}
+                }
+            }
+            if($e->{FromUserName} eq $self->user->id){#发送的消息
+                $msg->{source} = 'outer';
+                $msg->{class} = "send";
+                $msg->{sender_id} = $self->user->id;
+                if($self->is_group($e->{ToUserName})){
+                    $msg->{type} = "group_message";
+                    $msg->{group_id} = $e->{ToUserName};
+                }
+                else{
+                    $msg->{type} = "friend_message";
+                    $msg->{receiver_id} = $e->{ToUserName};
+                }
+            }
+            elsif($e->{ToUserName} eq $self->user->id){#接收的消息
+                $msg->{class} = "recv";
+                $msg->{receiver_id} = $self->user->id;
+                if($self->is_group($e->{FromUserName})){#接收到群组消息
+                    $msg->{type} = "group_message";
+                    $msg->{group_id} = $e->{FromUserName};
+                    my ($member_id,$content) = $msg->{content}=~/^(\@.+):<br\/>(.*)/g;
+                    if(defined $member_id and defined $content){
+                            $msg->{sender_id} = $member_id;
+                            $msg->{content} = $content;
                     }
                 }
-                elsif($e->{ToUserName} eq $self->user->id){#接收的消息
-                    $msg->{class} = "recv";
-                    $msg->{receiver_id} = $self->user->id;
-                    if($self->is_group($e->{FromUserName})){#接收到群组消息
-                        $msg->{type} = "group_message";
-                        $msg->{group_id} = $e->{FromUserName};
-                        my ($member_id,$content) = $msg->{content}=~/^(\@.+):<br\/>(.*)/g;
-                        if(defined $member_id and defined $content){
-                                $msg->{sender_id} = $member_id;
-                                $msg->{content} = $content;
-                        }
-                    }
-                    else{
-                        $msg->{type} = "friend_message";
-                        $msg->{sender_id} = $e->{FromUserName};
-                    }
+                else{
+                    $msg->{type} = "friend_message";
+                    $msg->{sender_id} = $e->{FromUserName};
                 }
-
-                $self->message_queue->put(Mojo::Weixin::Message->new($msg)); 
-            }#MsgType == 1 END
+            }
+            $msg->{content} = '[media]' if $msg->{format} eq "media";
+            $self->message_queue->put(Mojo::Weixin::Message->new($msg)); 
         }
     }
 
@@ -258,12 +289,51 @@ sub send_message{
         type => (ref $object eq "Mojo::Weixin::Group"?"group_message":"friend_message"),
         class => "send",
         format => "text", 
+        from  => "code",
     );
 
     $callback->($self,$msg) if ref $callback eq "CODE"; 
     $self->message_queue->put($msg);
 
 }
+sub send_media {
+    my $self = shift;
+    my $object = shift;
+    my $media = shift;
+    my $callback = shift;
+    if( ref($object) ne "Mojo::Weixin::Friend" and ref($object) ne "Mojo::Weixin::Group") {
+        $self->error("无效的发送消息对象");
+        return;
+    }
+    my $media_info = {};
+    if(ref $media eq ""){
+        $media_info->{media_path} = $media;
+    }
+    elsif(ref $media eq "HASH"){
+        $media_info = $media;
+    }
+    my $msg = Mojo::Weixin::Message->new(
+        id => $self->now(),
+        media_id   => $media_info->{media_id},
+        media_name => $media_info->{media_name},
+        media_path => $media_info->{media_path},
+        media_data => $media_info->{media_data},
+        media_mime => $media_info->{media_mime},
+        media_size => $media_info->{media_size},
+        media_mtime => $media_info->{media_mtime},
+        media_ext => $media_info->{media_ext},
+        content => "[media]($media_info->{media_path})",
+        sender_id => $self->user->id,
+        receiver_id => (ref $object eq "Mojo::Weixin::Friend"?$object->id : undef),
+        group_id =>(ref $object eq "Mojo::Weixin::Group"?$object->id : undef),
+        type => (ref $object eq "Mojo::Weixin::Group"?"group_message":"friend_message"),
+        class => "send",
+        format => "media",
+    );
+
+    $callback->($self,$msg) if ref $callback eq "CODE";
+    $self->message_queue->put($msg);
+}
 sub reply_message{
     my $self = shift;
     my $msg = shift;
